<?php

namespace Litecms\FundTransferSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\FundTransferSetting\Http\Requests\FundTransferSettingRequest;
use Litecms\FundTransferSetting\Interfaces\FundTransferSettingRepositoryInterface;
use Litecms\FundTransferSetting\Models\FundTransferSetting;

/**
 * Resource controller class for fund_transfer_setting.
 */
class FundTransferSettingResourceController extends BaseController
{

    /**
     * Initialize fund_transfer_setting resource controller.
     *
     * @param type FundTransferSettingRepositoryInterface $fund_transfer_setting
     *
     * @return null
     */
    public function __construct(FundTransferSettingRepositoryInterface $fund_transfer_setting)
    {
        parent::__construct();
        $this->repository = $fund_transfer_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\FundTransferSetting\Repositories\Criteria\FundTransferSettingResourceCriteria::class);
    }

    /**
     * Display a list of fund_transfer_setting.
     *
     * @return Response
     */
    public function index(FundTransferSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\FundTransferSetting\Repositories\Presenter\FundTransferSettingPresenter::class)
                ->$function();
        }

        $fund_transfer_settings = $this->repository->paginate();

        return $this->response->title(trans('fund_transfer_setting::fund_transfer_setting.names'))
            ->view('fund_transfer_setting::fund_transfer_setting.index', true)
            ->data(compact('fund_transfer_settings'))
            ->output();
    }

    /**
     * Display fund_transfer_setting.
     *
     * @param Request $request
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function show(FundTransferSettingRequest $request, FundTransferSetting $fund_transfer_setting)
    {

        if ($fund_transfer_setting->exists) {
            $view = 'fund_transfer_setting::fund_transfer_setting.show';
        } else {
            $view = 'fund_transfer_setting::fund_transfer_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('fund_transfer_setting::fund_transfer_setting.name'))
            ->data(compact('fund_transfer_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new fund_transfer_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FundTransferSettingRequest $request)
    {

        $fund_transfer_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('fund_transfer_setting::fund_transfer_setting.name')) 
            ->view('fund_transfer_setting::fund_transfer_setting.create', true) 
            ->data(compact('fund_transfer_setting'))
            ->output();
    }

    /**
     * Create new fund_transfer_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FundTransferSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $fund_transfer_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('fund_transfer_setting::fund_transfer_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting/' . $fund_transfer_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/fund_transfer_setting/fund_transfer_setting'))
                ->redirect();
        }

    }

    /**
     * Show fund_transfer_setting for editing.
     *
     * @param Request $request
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function edit(FundTransferSettingRequest $request, FundTransferSetting $fund_transfer_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('fund_transfer_setting::fund_transfer_setting.name'))
            ->view('fund_transfer_setting::fund_transfer_setting.edit', true)
            ->data(compact('fund_transfer_setting'))
            ->output();
    }

    /**
     * Update the fund_transfer_setting.
     *
     * @param Request $request
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function update(FundTransferSettingRequest $request, FundTransferSetting $fund_transfer_setting)
    {
        try {
            $attributes = $request->all();

            $fund_transfer_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('fund_transfer_setting::fund_transfer_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting/' . $fund_transfer_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting/' . $fund_transfer_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the fund_transfer_setting.
     *
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function destroy(FundTransferSettingRequest $request, FundTransferSetting $fund_transfer_setting)
    {
        try {

            $fund_transfer_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('fund_transfer_setting::fund_transfer_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting/' . $fund_transfer_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple fund_transfer_setting.
     *
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function delete(FundTransferSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('fund_transfer_setting::fund_transfer_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('fund_transfer_setting/fund_transfer_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/fund_transfer_setting/fund_transfer_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted fund_transfer_settings.
     *
     * @param Model   $fund_transfer_setting
     *
     * @return Response
     */
    public function restore(FundTransferSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('fund_transfer_setting::fund_transfer_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/fund_transfer_setting/fund_transfer_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/fund_transfer_setting/fund_transfer_setting/'))
                ->redirect();
        }

    }

}
