<?php

namespace Litecms\FundTransferSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\FundTransferSetting\Models\FundTransferSetting;

class FundTransferSettingPolicy
{

    /**
     * Determine if the given user can view the fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, FundTransferSetting $fund_transfer_setting)
    {
        if ($user->canDo('fund_transfer_setting.fund_transfer_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $fund_transfer_setting->user_id == user_id() && $fund_transfer_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('fund_transfer_setting.fund_transfer_setting.create');
    }

    /**
     * Determine if the given user can update the given fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, FundTransferSetting $fund_transfer_setting)
    {
        if ($user->canDo('fund_transfer_setting.fund_transfer_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $fund_transfer_setting->user_id == user_id() && $fund_transfer_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FundTransferSetting $fund_transfer_setting)
    {
        return $fund_transfer_setting->user_id == user_id() && $fund_transfer_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FundTransferSetting $fund_transfer_setting)
    {
        if ($user->canDo('fund_transfer_setting.fund_transfer_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given fund_transfer_setting.
     *
     * @param UserPolicy $user
     * @param FundTransferSetting $fund_transfer_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FundTransferSetting $fund_transfer_setting)
    {
        if ($user->canDo('fund_transfer_setting.fund_transfer_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
